# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that implements the popup menu for the
notification area.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import Menu

class PopupMenu(Menu):
	"""
	This class defines the behavior for the popup menu for the
	notification area.
	"""

	def __init__(self, player):
		"""
		Initialize object.

		@param self: Reference to the PopupMenu instance.
		@type self: A PopupMenu object.

		@param player: Reference to the Player
		@type player: A Player object.
		"""
		Menu.__init__(self)
		self.__init_attributes(player)
		self.__set_properties()
		player.connect("show-popup", self.__show_popup_cb)

	def __init_attributes(self, player):
		"""
		Initialize data attributes.

		@param self: Reference to the PopupMenu instance.
		@type self: A PopupMenu object.

		@param player: Reference to the Player
		@type player: A Player object.
		"""
		self.__player = player
		from PlayMenuItem import PlayMenuItem
		self.__toggle_play_item = PlayMenuItem(player)
		from StationsMenuItem import StationsMenuItem
		self.__station_item = StationsMenuItem(player)
		from HelpMenuItem import HelpMenuItem
		self.__help_item = HelpMenuItem(player)
		from AboutMenuItem import AboutMenuItem
		self.__about_item = AboutMenuItem(player)
		from QuitMenuItem import QuitMenuItem
		self.__quit_item = QuitMenuItem(player)
		return

	def __set_properties(self):
		"""
		Set default properties.

		@param self: Reference to the PopupMenu instance.
		@type self: A PopupMenu object.
		"""
		from gtk import MenuItem, SeparatorMenuItem
		self.append(self.__toggle_play_item)
		self.append(SeparatorMenuItem())
		self.append(self.__station_item)
		self.append(self.__help_item)
		self.append(self.__about_item)
		self.append(SeparatorMenuItem())
		self.append(self.__quit_item)
		self.show_all()
		return

	def __show_popup_cb(self, player, data):
		button, time, icon = data
		self.__player.response()
		from gtk import status_icon_position_menu
		self.popup(None, None, status_icon_position_menu, button=button, activate_time=time, data=icon)
		self.show_all()
		self.__player.response()
		return
